@@ -15,7 +15,9 @@ from urh.controller.dialogs.SendDialog import SendDialog
 from urh.models.GeneratorListModel import GeneratorListModel
 from urh.models.GeneratorTableModel import GeneratorTableModel
 from urh.models.GeneratorTreeModel import GeneratorTreeModel
-from urh.plugins.NetworkSDRInterface.NetworkSDRInterfacePlugin import NetworkSDRInterfacePlugin
+from urh.plugins.NetworkSDRInterface.NetworkSDRInterfacePlugin import (
+    NetworkSDRInterfacePlugin,
+)
 from urh.plugins.PluginManager import PluginManager
 from urh.plugins.RfCat.RfCatPlugin import RfCatPlugin
 from urh.plugins.FlipperZeroSub.FlipperZeroSubPlugin import FlipperZeroSubPlugin
@@ -35,7 +37,12 @@ from urh.util.ProjectManager import ProjectManager
 
 
 class GeneratorTabController(QWidget):
-    def __init__(self, compare_frame_controller: CompareFrameController, project_manager: ProjectManager, parent=None):
+    def __init__(
+        self,
+        compare_frame_controller: CompareFrameController,
+        project_manager: ProjectManager,
+        parent=None,
+    ):
         super().__init__(parent)
         self.ui = Ui_GeneratorTab()
         self.ui.setupUi(self)
@@ -45,12 +52,16 @@ class GeneratorTabController(QWidget):
 
         self.ui.treeProtocols.setHeaderHidden(True)
         self.tree_model = GeneratorTreeModel(compare_frame_controller)
-        self.tree_model.set_root_item(compare_frame_controller.proto_tree_model.rootItem)
+        self.tree_model.set_root_item(
+            compare_frame_controller.proto_tree_model.rootItem
+        )
         self.tree_model.controller = self
         self.ui.treeProtocols.setModel(self.tree_model)
 
-        self.table_model = GeneratorTableModel(compare_frame_controller.proto_tree_model.rootItem,
-                                               compare_frame_controller.decodings)
+        self.table_model = GeneratorTableModel(
+            compare_frame_controller.proto_tree_model.rootItem,
+            compare_frame_controller.decodings,
+        )
         self.table_model.controller = self
         self.ui.tableMessages.setModel(self.table_model)
 
@@ -91,7 +102,9 @@ class GeneratorTabController(QWidget):
     @property
     def selected_message(self) -> Message:
         selected_msg_index = self.selected_message_index
-        if selected_msg_index == -1 or selected_msg_index >= len(self.table_model.protocol.messages):
+        if selected_msg_index == -1 or selected_msg_index >= len(
+            self.table_model.protocol.messages
+        ):
             return None
 
         return self.table_model.protocol.messages[selected_msg_index]
@@ -106,8 +119,14 @@ class GeneratorTabController(QWidget):
 
     @property
     def total_modulated_samples(self) -> int:
-        return sum(int(len(msg.encoded_bits) * self.__get_modulator_of_message(msg).samples_per_symbol + msg.pause)
-                   for msg in self.table_model.protocol.messages)
+        return sum(
+            int(
+                len(msg.encoded_bits)
+                * self.__get_modulator_of_message(msg).samples_per_symbol
+                + msg.pause
+            )
+            for msg in self.table_model.protocol.messages
+        )
 
     @modulators.setter
     def modulators(self, value):
@@ -116,19 +135,36 @@ class GeneratorTabController(QWidget):
 
     def create_connects(self, compare_frame_controller):
         compare_frame_controller.proto_tree_model.modelReset.connect(self.refresh_tree)
-        compare_frame_controller.participant_changed.connect(self.table_model.refresh_vertical_header)
+        compare_frame_controller.participant_changed.connect(
+            self.table_model.refresh_vertical_header
+        )
         self.ui.btnEditModulation.clicked.connect(self.show_modulation_dialog)
-        self.ui.cBoxModulations.currentIndexChanged.connect(self.on_selected_modulation_changed)
-        self.ui.tableMessages.selectionModel().selectionChanged.connect(self.on_table_selection_changed)
+        self.ui.cBoxModulations.currentIndexChanged.connect(
+            self.on_selected_modulation_changed
+        )
+        self.ui.tableMessages.selectionModel().selectionChanged.connect(
+            self.on_table_selection_changed
+        )
         self.ui.tableMessages.encodings_updated.connect(self.on_table_selection_changed)
-        self.table_model.undo_stack.indexChanged.connect(self.on_undo_stack_index_changed)
-        self.table_model.protocol.qt_signals.line_duplicated.connect(self.refresh_pause_list)
-        self.table_model.protocol.qt_signals.fuzzing_started.connect(self.on_fuzzing_started)
+        self.table_model.undo_stack.indexChanged.connect(
+            self.on_undo_stack_index_changed
+        )
+        self.table_model.protocol.qt_signals.line_duplicated.connect(
+            self.refresh_pause_list
+        )
+        self.table_model.protocol.qt_signals.fuzzing_started.connect(
+            self.on_fuzzing_started
+        )
         self.table_model.protocol.qt_signals.current_fuzzing_message_changed.connect(
-            self.on_current_fuzzing_message_changed)
-        self.table_model.protocol.qt_signals.fuzzing_finished.connect(self.on_fuzzing_finished)
+            self.on_current_fuzzing_message_changed
+        )
+        self.table_model.protocol.qt_signals.fuzzing_finished.connect(
+            self.on_fuzzing_finished
+        )
         self.table_model.first_protocol_added.connect(self.on_first_protocol_added)
-        self.label_list_model.protolabel_fuzzing_status_changed.connect(self.set_fuzzing_ui_status)
+        self.label_list_model.protolabel_fuzzing_status_changed.connect(
+            self.set_fuzzing_ui_status
+        )
         self.ui.cbViewType.currentIndexChanged.connect(self.on_view_type_changed)
         self.ui.btnSend.clicked.connect(self.on_btn_send_clicked)
         self.ui.btnSave.clicked.connect(self.on_btn_save_clicked)
@@ -137,29 +173,46 @@ class GeneratorTabController(QWidget):
         self.project_manager.project_updated.connect(self.on_project_updated)
 
         self.table_model.vertical_header_color_status_changed.connect(
-            self.ui.tableMessages.on_vertical_header_color_status_changed)
+            self.ui.tableMessages.on_vertical_header_color_status_changed
+        )
 
-        self.label_list_model.protolabel_removed.connect(self.handle_proto_label_removed)
+        self.label_list_model.protolabel_removed.connect(
+            self.handle_proto_label_removed
+        )
 
         self.ui.lWPauses.item_edit_clicked.connect(self.edit_pause_item)
         self.ui.lWPauses.edit_all_items_clicked.connect(self.edit_all_pause_items)
-        self.ui.lWPauses.itemSelectionChanged.connect(self.on_lWpauses_selection_changed)
+        self.ui.lWPauses.itemSelectionChanged.connect(
+            self.on_lWpauses_selection_changed
+        )
         self.ui.lWPauses.lost_focus.connect(self.on_lWPauses_lost_focus)
         self.ui.lWPauses.doubleClicked.connect(self.on_lWPauses_double_clicked)
         self.ui.btnGenerate.clicked.connect(self.generate_file)
-        self.label_list_model.protolabel_fuzzing_status_changed.connect(self.handle_plabel_fuzzing_state_changed)
+        self.label_list_model.protolabel_fuzzing_status_changed.connect(
+            self.handle_plabel_fuzzing_state_changed
+        )
         self.ui.btnFuzz.clicked.connect(self.on_btn_fuzzing_clicked)
         self.ui.tableMessages.create_label_triggered.connect(self.create_fuzzing_label)
         self.ui.tableMessages.edit_label_triggered.connect(self.show_fuzzing_dialog)
-        self.ui.listViewProtoLabels.selection_changed.connect(self.handle_label_selection_changed)
-        self.ui.listViewProtoLabels.edit_on_item_triggered.connect(self.show_fuzzing_dialog)
+        self.ui.listViewProtoLabels.selection_changed.connect(
+            self.handle_label_selection_changed
+        )
+        self.ui.listViewProtoLabels.edit_on_item_triggered.connect(
+            self.show_fuzzing_dialog
+        )
 
         self.ui.btnNetworkSDRSend.clicked.connect(self.on_btn_network_sdr_clicked)
         self.ui.btnRfCatSend.clicked.connect(self.on_btn_rfcat_clicked)
 
-        self.network_sdr_plugin.sending_status_changed.connect(self.on_network_sdr_sending_status_changed)
-        self.network_sdr_plugin.sending_stop_requested.connect(self.on_network_sdr_sending_stop_requested)
-        self.network_sdr_plugin.current_send_message_changed.connect(self.on_send_message_changed)
+        self.network_sdr_plugin.sending_status_changed.connect(
+            self.on_network_sdr_sending_status_changed
+        )
+        self.network_sdr_plugin.sending_stop_requested.connect(
+            self.on_network_sdr_sending_stop_requested
+        )
+        self.network_sdr_plugin.current_send_message_changed.connect(
+            self.on_send_message_changed
+        )
 
         # Flipper Zero
         self.ui.btnFZSave.clicked.connect(self.on_btn_FZSave_clicked)
@@ -174,7 +227,10 @@ class GeneratorTabController(QWidget):
     def refresh_table(self):
         self.table_model.update()
         self.ui.tableMessages.resize_columns()
-        is_data_there = self.table_model.display_data is not None and len(self.table_model.display_data) > 0
+        is_data_there = (
+            self.table_model.display_data is not None
+            and len(self.table_model.display_data) > 0
+        )
         self.ui.btnSend.setEnabled(is_data_there)
         self.ui.btnGenerate.setEnabled(is_data_there)
 
@@ -256,16 +312,27 @@ class GeneratorTabController(QWidget):
                 selected_message = self.table_model.protocol.messages[min_row]
                 preselected_index = selected_message.modulator_index
             except IndexError:
-                selected_message = Message([1, 0, 1, 0, 1, 0, 1, 0, 1, 1, 0, 1, 0, 0], 0, [], MessageType("empty"))
+                selected_message = Message(
+                    [1, 0, 1, 0, 1, 0, 1, 0, 1, 1, 0, 1, 0, 0],
+                    0,
+                    [],
+                    MessageType("empty"),
+                )
         else:
-            selected_message = Message([1, 0, 1, 0, 1, 0, 1, 0, 1, 1, 0, 1, 0, 0], 0, [], MessageType("empty"))
+            selected_message = Message(
+                [1, 0, 1, 0, 1, 0, 1, 0, 1, 1, 0, 1, 0, 0], 0, [], MessageType("empty")
+            )
             if len(self.table_model.protocol.messages) > 0:
-                selected_message.samples_per_symbol = self.table_model.protocol.messages[0].samples_per_symbol
+                selected_message.samples_per_symbol = (
+                    self.table_model.protocol.messages[0].samples_per_symbol
+                )
 
         for m in self.modulators:
             m.default_sample_rate = self.project_manager.device_conf["sample_rate"]
 
-        modulator_dialog = ModulatorDialog(self.modulators, tree_model=self.tree_model, parent=self.parent())
+        modulator_dialog = ModulatorDialog(
+            self.modulators, tree_model=self.tree_model, parent=self.parent()
+        )
         modulator_dialog.ui.comboBoxCustomModulations.setCurrentIndex(preselected_index)
 
         modulator_dialog.finished.connect(self.refresh_modulators)
@@ -280,7 +347,9 @@ class GeneratorTabController(QWidget):
     def init_rfcat_plugin(self):
         self.set_rfcat_button_visibility()
         self.rfcat_plugin = RfCatPlugin()
-        self.rfcat_plugin.current_send_message_changed.connect(self.on_send_message_changed)
+        self.rfcat_plugin.current_send_message_changed.connect(
+            self.on_send_message_changed
+        )
         self.ui.btnRfCatSend.setEnabled(self.rfcat_plugin.rfcat_is_found)
 
     @pyqtSlot()
@@ -314,7 +383,9 @@ class GeneratorTabController(QWidget):
         self.label_list_model.message = message
         decoder_name = message.decoder.name
         metrics = QFontMetrics(self.ui.lEncodingValue.font())
-        elidedName = metrics.elidedText(decoder_name, Qt.ElideRight, self.ui.lEncodingValue.width())
+        elidedName = metrics.elidedText(
+            decoder_name, Qt.ElideRight, self.ui.lEncodingValue.width()
+        )
         self.ui.lEncodingValue.setText(elidedName)
         self.ui.lEncodingValue.setToolTip(decoder_name)
         self.ui.cBoxModulations.blockSignals(True)
@@ -326,8 +397,13 @@ class GeneratorTabController(QWidget):
     def edit_pause_item(self, index: int):
         message = self.table_model.protocol.messages[index]
         cur_len = message.pause
-        new_len, ok = QInputDialog.getInt(self, self.tr("Enter new Pause Length"),
-                                          self.tr("Pause Length:"), cur_len, 0)
+        new_len, ok = QInputDialog.getInt(
+            self,
+            self.tr("Enter new Pause Length"),
+            self.tr("Pause Length:"),
+            cur_len,
+            0,
+        )
         if ok:
             message.pause = new_len
             self.refresh_pause_list()
@@ -336,8 +412,13 @@ class GeneratorTabController(QWidget):
     def edit_all_pause_items(self):
         message = self.table_model.protocol.messages[0]
         cur_len = message.pause
-        new_len, ok = QInputDialog.getInt(self, self.tr("Enter new Pause Length"),
-                                          self.tr("Pause Length:"), cur_len, 0)
+        new_len, ok = QInputDialog.getInt(
+            self,
+            self.tr("Enter new Pause Length"),
+            self.tr("Pause Length:"),
+            cur_len,
+            0,
+        )
         if ok:
             for message in self.table_model.protocol.messages:
                 message.pause = new_len
@@ -356,8 +437,12 @@ class GeneratorTabController(QWidget):
 
         fmt_str = "Pause ({1:d}-{2:d}) <{0:d} samples ({3})>"
         for i, pause in enumerate(self.table_model.protocol.pauses):
-            sr = self.__get_modulator_of_message(self.table_model.protocol.messages[i]).sample_rate
-            item = fmt_str.format(pause, i + 1, i + 2, Formatter.science_time(pause / sr))
+            sr = self.__get_modulator_of_message(
+                self.table_model.protocol.messages[i]
+            ).sample_rate
+            item = fmt_str.format(
+                pause, i + 1, i + 2, Formatter.science_time(pause / sr)
+            )
             self.ui.lWPauses.addItem(item)
 
         self.refresh_estimated_time()
@@ -383,7 +468,10 @@ class GeneratorTabController(QWidget):
             total_samples = self.total_modulated_samples
             buffer = self.prepare_modulation_buffer(total_samples, show_error=False)
             if buffer is None:
-                Errors.generic_error(self.tr("File too big"), self.tr("This file would get too big to save."))
+                Errors.generic_error(
+                    self.tr("File too big"),
+                    self.tr("This file would get too big to save."),
+                )
                 self.unsetCursor()
                 return
             modulated_samples = self.modulate_data(buffer)
@@ -392,7 +480,9 @@ class GeneratorTabController(QWidget):
             except Exception as e:
                 logger.exception(e)
                 sample_rate = 1e6
-            FileOperator.ask_signal_file_name_and_save("generated", modulated_samples, sample_rate=sample_rate, parent=self)
+            FileOperator.ask_signal_file_name_and_save(
+                "generated", modulated_samples, sample_rate=sample_rate, parent=self
+            )
         except Exception as e:
             Errors.exception(e)
             self.unsetCursor()
@@ -402,23 +492,27 @@ class GeneratorTabController(QWidget):
         n = 2 if dtype == np.int8 else 4 if dtype == np.int16 else 8
 
         memory_size_for_buffer = total_samples * n
-        logger.debug("Allocating {0:.2f}MB for modulated samples".format(memory_size_for_buffer / (1024 ** 2)))
+        logger.debug(
+            "Allocating {0:.2f}MB for modulated samples".format(
+                memory_size_for_buffer / (1024**2)
+            )
+        )
         try:
             # allocate it three times as we need the same amount for the sending process
-            IQArray(None, dtype=dtype, n=3*total_samples)
+            IQArray(None, dtype=dtype, n=3 * total_samples)
         except MemoryError:
             # will go into continuous mode in this case
             if show_error:
-                Errors.not_enough_ram_for_sending_precache(3*memory_size_for_buffer)
+                Errors.not_enough_ram_for_sending_precache(3 * memory_size_for_buffer)
             return None
 
         return IQArray(None, dtype=dtype, n=total_samples)
 
     def modulate_data(self, buffer: IQArray) -> IQArray:
         """
-        
+
         :param buffer: Buffer in which the modulated data shall be written, initialized with zeros
-        :return: 
+        :return:
         """
         self.ui.prBarGeneration.show()
         self.ui.prBarGeneration.setValue(0)
@@ -431,7 +525,7 @@ class GeneratorTabController(QWidget):
             modulator = self.__get_modulator_of_message(message)
             # We do not need to modulate the pause extra, as result is already initialized with zeros
             modulated = modulator.modulate(start=0, data=message.encoded_bits, pause=0)
-            buffer[pos:pos + len(modulated)] = modulated
+            buffer[pos : pos + len(modulated)] = modulated
             pos += len(modulated) + message.pause
             self.modulation_msg_indices.append(pos)
             self.ui.prBarGeneration.setValue(i + 1)
@@ -445,9 +539,16 @@ class GeneratorTabController(QWidget):
         view = self.ui.cbViewType.currentIndex()
 
         if self.label_list_model.message is not None:
-            msg_index = self.table_model.protocol.messages.index(self.label_list_model.message)
-            fdc = FuzzingDialog(protocol=self.table_model.protocol, label_index=label_index,
-                                msg_index=msg_index, proto_view=view, parent=self)
+            msg_index = self.table_model.protocol.messages.index(
+                self.label_list_model.message
+            )
+            fdc = FuzzingDialog(
+                protocol=self.table_model.protocol,
+                label_index=label_index,
+                msg_index=msg_index,
+                proto_view=view,
+                parent=self,
+            )
             fdc.show()
             fdc.finished.connect(self.on_fuzzing_dialog_finished)
 
@@ -488,7 +589,11 @@ class GeneratorTabController(QWidget):
     @pyqtSlot()
     def set_fuzzing_ui_status(self):
         btn_was_enabled = self.ui.btnFuzz.isEnabled()
-        fuzz_active = any(lbl.active_fuzzing for msg in self.table_model.protocol.messages for lbl in msg.message_type)
+        fuzz_active = any(
+            lbl.active_fuzzing
+            for msg in self.table_model.protocol.messages
+            for lbl in msg.message_type
+        )
         self.ui.btnFuzz.setEnabled(fuzz_active)
         if self.ui.btnFuzz.isEnabled() and not btn_was_enabled:
             font = self.ui.btnFuzz.font()
@@ -514,7 +619,14 @@ class GeneratorTabController(QWidget):
         update = False
 
         for msg in self.table_model.protocol.messages:
-            i = next((i for i, d in enumerate(encodings_from_file) if d.name == msg.decoder.name), 0)
+            i = next(
+                (
+                    i
+                    for i, d in enumerate(encodings_from_file)
+                    if d.name == msg.decoder.name
+                ),
+                0,
+            )
             if msg.decoder != encodings_from_file[i]:
                 update = True
                 msg.decoder = encodings_from_file[i]
@@ -533,18 +645,25 @@ class GeneratorTabController(QWidget):
             return
 
         avg_msg_len = numpy.mean([len(msg.encoded_bits) for msg in c.messages])
-        avg_samples_per_symbol = numpy.mean([m.samples_per_symbol for m in self.modulators])
+        avg_samples_per_symbol = numpy.mean(
+            [m.samples_per_symbol for m in self.modulators]
+        )
         avg_sample_rate = numpy.mean([m.sample_rate for m in self.modulators])
         pause_samples = sum(c.pauses)
         nsamples = c.num_messages * avg_msg_len * avg_samples_per_symbol + pause_samples
 
         self.ui.lEstimatedTime.setText(
-            locale.format_string("Estimated Time: %.04f seconds", nsamples / avg_sample_rate))
+            locale.format_string(
+                "Estimated Time: %.04f seconds", nsamples / avg_sample_rate
+            )
+        )
 
     @pyqtSlot(int, int, int)
     def create_fuzzing_label(self, msg_index: int, start: int, end: int):
         con = self.table_model.protocol
-        start, end = con.convert_range(start, end - 1, self.ui.cbViewType.currentIndex(), 0, False, msg_index)
+        start, end = con.convert_range(
+            start, end - 1, self.ui.cbViewType.currentIndex(), 0, False, msg_index
+        )
         lbl = con.create_fuzzing_label(start, end, msg_index)
         self.show_fuzzing_dialog(con.protocol_labels.index(lbl))
 
@@ -561,8 +680,9 @@ class GeneratorTabController(QWidget):
         except IndexError:
             return
         if label.show and self.selected_message:
-            start, end = self.selected_message.get_label_range(lbl=label, view=self.table_model.proto_view,
-                                                               decode=False)
+            start, end = self.selected_message.get_label_range(
+                lbl=label, view=self.table_model.proto_view, decode=False
+            )
             indx = self.table_model.index(0, int((start + end) / 2))
             self.ui.tableMessages.scrollTo(indx)
 
@@ -587,18 +707,31 @@ class GeneratorTabController(QWidget):
             try:
                 if modulated_data is not None:
                     try:
-                        dialog = SendDialog(self.project_manager, modulated_data=modulated_data,
-                                            modulation_msg_indices=self.modulation_msg_indices, parent=self)
+                        dialog = SendDialog(
+                            self.project_manager,
+                            modulated_data=modulated_data,
+                            modulation_msg_indices=self.modulation_msg_indices,
+                            parent=self,
+                        )
                     except MemoryError:
                         # Not enough memory for device buffer so we need to create a continuous send dialog
                         del modulated_data
                         Errors.not_enough_ram_for_sending_precache(None)
-                        dialog = ContinuousSendDialog(self.project_manager,
-                                                      self.table_model.protocol.messages,
-                                                      self.modulators, total_samples, parent=self)
+                        dialog = ContinuousSendDialog(
+                            self.project_manager,
+                            self.table_model.protocol.messages,
+                            self.modulators,
+                            total_samples,
+                            parent=self,
+                        )
                 else:
-                    dialog = ContinuousSendDialog(self.project_manager, self.table_model.protocol.messages,
-                                                  self.modulators, total_samples, parent=self)
+                    dialog = ContinuousSendDialog(
+                        self.project_manager,
+                        self.table_model.protocol.messages,
+                        self.modulators,
+                        total_samples,
+                        parent=self,
+                    )
             except OSError as e:
                 logger.exception(e)
                 return
@@ -607,7 +740,9 @@ class GeneratorTabController(QWidget):
                 dialog.close()
                 return
 
-            dialog.device_parameters_changed.connect(self.project_manager.set_device_parameters)
+            dialog.device_parameters_changed.connect(
+                self.project_manager.set_device_parameters
+            )
             dialog.show()
             dialog.graphics_view.show_full_scene(reinitialize=True)
         except Exception as e:
@@ -616,16 +751,22 @@ class GeneratorTabController(QWidget):
 
     @pyqtSlot()
     def on_btn_save_clicked(self):
-        filename = FileOperator.ask_save_file_name("profile.fuzz.xml", caption="Save fuzzing profile")
+        filename = FileOperator.ask_save_file_name(
+            "profile.fuzz.xml", caption="Save fuzzing profile"
+        )
         if filename:
-            self.table_model.protocol.to_xml_file(filename,
-                                                  decoders=self.project_manager.decodings,
-                                                  participants=self.project_manager.participants,
-                                                  modulators=self.modulators)
+            self.table_model.protocol.to_xml_file(
+                filename,
+                decoders=self.project_manager.decodings,
+                participants=self.project_manager.participants,
+                modulators=self.modulators,
+            )
 
     @pyqtSlot()
     def on_btn_open_clicked(self):
-        dialog = FileOperator.get_open_dialog(directory_mode=False, parent=self, name_filter="fuzz")
+        dialog = FileOperator.get_open_dialog(
+            directory_mode=False, parent=self, name_filter="fuzz"
+        )
         if dialog.exec_():
             for filename in dialog.selectedFiles():
                 self.load_from_file(filename)
@@ -661,15 +802,23 @@ class GeneratorTabController(QWidget):
 
     @pyqtSlot()
     def on_btn_FZSave_clicked(self):
-        filename, _ = QFileDialog.getSaveFileName(self, self.tr("Choose file"), directory=FileOperator.RECENT_PATH,
-                                                  filter="SUB files (*.sub);;All files (*.*)")
+        filename, _ = QFileDialog.getSaveFileName(
+            self,
+            self.tr("Choose file"),
+            directory=FileOperator.RECENT_PATH,
+            filter="SUB files (*.sub);;All files (*.*)",
+        )
         if len(filename) > 0:
             if not filename.endswith(".sub"):
-                filename = filename+".sub"
+                filename = filename + ".sub"
 
             messages = self.table_model.protocol.messages
-            sample_rates = [self.__get_modulator_of_message(msg).sample_rate for msg in messages]
-            self.flipperzerosub_plugin.write_sub_file(filename, messages, sample_rates, self.modulators, self.project_manager)
+            sample_rates = [
+                self.__get_modulator_of_message(msg).sample_rate for msg in messages
+            ]
+            self.flipperzerosub_plugin.write_sub_file(
+                filename, messages, sample_rates, self.modulators, self.project_manager
+            )
         else:
             logger.debug("Filename was empty!")
 
@@ -677,7 +826,9 @@ class GeneratorTabController(QWidget):
     def on_btn_network_sdr_clicked(self):
         if not self.network_sdr_plugin.is_sending:
             messages = self.table_model.protocol.messages
-            sample_rates = [self.__get_modulator_of_message(msg).sample_rate for msg in messages]
+            sample_rates = [
+                self.__get_modulator_of_message(msg).sample_rate for msg in messages
+            ]
             self.network_sdr_plugin.start_message_sending_thread(messages, sample_rates)
         else:
             self.network_sdr_plugin.stop_sending_thread()
@@ -687,7 +838,10 @@ class GeneratorTabController(QWidget):
         self.ui.btnNetworkSDRSend.setChecked(is_sending)
         self.ui.btnNetworkSDRSend.setEnabled(True)
         self.ui.btnNetworkSDRSend.setToolTip(
-            "Sending in progress" if is_sending else self.network_sdr_button_orig_tooltip)
+            "Sending in progress"
+            if is_sending
+            else self.network_sdr_button_orig_tooltip
+        )
         if not is_sending:
             self.ui.tableMessages.clearSelection()
 
@@ -704,9 +858,12 @@ class GeneratorTabController(QWidget):
     def on_btn_rfcat_clicked(self):
         if not self.rfcat_plugin.is_sending:
             messages = self.table_model.protocol.messages
-            sample_rates = [self.__get_modulator_of_message(msg).sample_rate for msg in messages]
-            self.rfcat_plugin.start_message_sending_thread(messages, sample_rates, self.modulators,
-                                                           self.project_manager)
+            sample_rates = [
+                self.__get_modulator_of_message(msg).sample_rate for msg in messages
+            ]
+            self.rfcat_plugin.start_message_sending_thread(
+                messages, sample_rates, self.modulators, self.project_manager
+            )
         else:
             self.rfcat_plugin.stop_sending_thread()
 
