@@ -1,14 +1,16 @@
 from PyQt5.QtCore import pyqtSlot
 from PyQt5.QtWidgets import QWidget
 
-from urh import constants
+from urh import settings
 from urh.controller.dialogs.ModulatorDialog import ModulatorDialog
 from urh.signalprocessing.Modulator import Modulator
 from urh.ui.ui_modulation_settings_widget import Ui_ModulationSettings
 
 
 class ModulationSettingsWidget(QWidget):
-    def __init__(self, modulators, selected_index=0, signal_tree_model=None, parent=None):
+    def __init__(
+        self, modulators, selected_index=0, signal_tree_model=None, parent=None
+    ):
         """
 
         :type modulators: list of Modulator
@@ -18,8 +20,12 @@ class ModulationSettingsWidget(QWidget):
         self.ui = Ui_ModulationSettings()
         self.ui.setupUi(self)
 
-        self.ui.labelModulationProfile.setVisible(constants.SETTINGS.value("multiple_modulations", False, bool))
-        self.ui.comboBoxModulationProfiles.setVisible(constants.SETTINGS.value("multiple_modulations", False, bool))
+        self.ui.labelModulationProfile.setVisible(
+            settings.read("multiple_modulations", False, bool)
+        )
+        self.ui.comboBoxModulationProfiles.setVisible(
+            settings.read("multiple_modulations", False, bool)
+        )
 
         self.signal_tree_model = signal_tree_model
         self.modulators = modulators  # type: list[Modulator]
@@ -38,11 +44,17 @@ class ModulationSettingsWidget(QWidget):
     @selected_modulator.setter
     def selected_modulator(self, value: Modulator):
         if value in self.modulators:
-            self.ui.comboBoxModulationProfiles.setCurrentIndex(self.modulators.index(value))
+            self.ui.comboBoxModulationProfiles.setCurrentIndex(
+                self.modulators.index(value)
+            )
 
     def create_connects(self):
-        self.ui.comboBoxModulationProfiles.currentIndexChanged.connect(self.on_cb_modulation_type_current_index_changed)
-        self.ui.btnConfigurationDialog.clicked.connect(self.on_btn_configuration_dialog_clicked)
+        self.ui.comboBoxModulationProfiles.currentIndexChanged.connect(
+            self.on_cb_modulation_type_current_index_changed
+        )
+        self.ui.btnConfigurationDialog.clicked.connect(
+            self.on_btn_configuration_dialog_clicked
+        )
 
     def show_selected_modulation_infos(self):
         modulator = self.selected_modulator
@@ -61,8 +73,12 @@ class ModulationSettingsWidget(QWidget):
 
     @pyqtSlot()
     def on_btn_configuration_dialog_clicked(self):
-        dialog = ModulatorDialog(self.modulators, tree_model=self.signal_tree_model, parent=self)
-        dialog.ui.comboBoxCustomModulations.setCurrentIndex(self.ui.comboBoxModulationProfiles.currentIndex())
+        dialog = ModulatorDialog(
+            self.modulators, tree_model=self.signal_tree_model, parent=self
+        )
+        dialog.ui.comboBoxCustomModulations.setCurrentIndex(
+            self.ui.comboBoxModulationProfiles.currentIndex()
+        )
         dialog.finished.connect(self.refresh_modulators_from_dialog)
         dialog.show()
         dialog.initialize("10101011010010")
@@ -80,9 +96,11 @@ class ModulationSettingsWidget(QWidget):
         self.ui.comboBoxModulationProfiles.setCurrentIndex(current_index)
         self.show_selected_modulation_infos()
 
-if __name__ == '__main__':
+
+if __name__ == "__main__":
     from PyQt5.QtWidgets import QApplication
+
     app = QApplication([""])
     w = ModulationSettingsWidget([Modulator("test")])
     w.show()
-    app.exec()
\ No newline at end of file
+    app.exec()
